#!/bin/bash

#     Copyright (C) 2009 Michael Verret <michael.verret@gmail.com>
#
#            This script is released under the terms of the:
#                      GNU GENERAL PUBLIC LICENSE
#                        Version 3, 29 June 2007
#                http://www.gnu.org/licenses/gpl-3.0.txt
#
# This is a Bash shell script written to automate the process of
# generating software packages suitable for use with Zenwalk Linux.
#
# Zenwalk Linux is a GNU/Linux operating system.
#
#              For more information on Zenwalk Linux visit:
#                        http://www.zenwalk.org/
#
# Bash is a free software Unix shell written for the GNU Project.
#
#                   For more information on Bash visit:
#           http://tiswww.case.edu/php/chet/bash/bashtop.html


# Package variables:
#_______________________________________________________________________
Summary="Experimental Radeon HD video driver"
Driver_Type="video"
Source_Module="radeonhd"
Source_Category="driver"
Source_Version="1.2.5"
Source_Format="tar.bz2"
Flag_Arch="i686"
Package_Arch="${Flag_Arch}"
Package_Release="62"
Package_Build="1"
Source_Name="xf86-${Driver_Type}-${Source_Module}"
Source_URL="http://xorg.freedesktop.org/releases/individual/${Source_Category}/"
Package_Name="xorg-${Source_Category}-${Source_Module}"
Package_Version="${Source_Version}"
File_Image=" "
File_Misc=" "
File_Patch=" "
File_Script=" \
	build-${Package_Name}.sh"
Special_Docs=" "
Desc_Line_00=": (${Summary})"
Desc_Line_01=":"
Desc_Line_02=": This package provides the driver for the Radeon r5xx and r6xx family"
Desc_Line_03=": of chipsets, including the X1550, X1300, X1550, X1600, FireGL"
Desc_Line_04=": V3300/V3350, FireMV 2250, X1800, FireGL V5300/V7200/V7300/V7350,"
Desc_Line_05=": X1300 XT, X1600, FireGL V3400/V5200 X1300, X1650, X1950 Pro/GT,"
Desc_Line_06=": X1650, X1900, X1950, FireStream 2U, HD 2900 XT, HD 2400 Pro/XT,"
Desc_Line_07=": HD 2600 Pro/XT, Mobility X1300, X1350, Mobility X1400, X1450,"
Desc_Line_08=": X2300, Mobility X1600, X1700, Mobility FireGL V5200, V5250,"
Desc_Line_09=": Mobility X1800, X1900, Mobility FireGL V7100, V7200, Mobility HD 2300,"
Desc_Line_10=": Mobility HD 2400, Mobility HD 2600, and Radeon X1200."
# BuildRequires: 
# Requires:


# Constant variables:
#_______________________________________________________________________
Build_Root=$(pwd)
Source_Duo="${Source_Name}-${Source_Version}"
Source_Title="${Source_Duo}.${Source_Format}"
Package_Duo="${Package_Name}-${Package_Version}"
Package_Title="${Package_Duo}-${Package_Arch}-${Package_Release}.${Package_Build}"
Package_Root="${Build_Root}/${Package_Title}"
Standard_Docs="AUTHORS BUGS COPYING ChangeLog INSTALL LICENSE NEWS README"
Custom_Files="${File_Image} ${File_Misc} ${File_Patch} ${File_Script}"


# Build & install:
#_______________________________________________________________________
for Each in ${Source_Duo} ${Package_Name}-${Package_Version}-${Package_Arch} ; do
	if [ -d ${Each} ] ; then
		rm -rf ${Each}
	fi
done
for Each in ${Package_Title}.dep ${Package_Title}.md5 ${Package_Title}.src.md5 \
	${Package_Title}.src.tbz ${Package_Title}.tgz ; do
	if [ -e ${Each} ] ; then
		rm -rf ${Each}
	fi
done
if [ -e ${Source_Title} ] ; then
	echo "${Source_Title} already downloaded"
else
	wget -c -t 0 -T 50 -w 0 ${Source_URL}${Source_Title}
fi

for Archive in ${Source_Title} ; do
	File_Type=$(file -biz "${Archive}")
	unset Command
	case "${File_Type}" in
		*application/x-tar*)
			Command="tar -xf" ;;
		*application/x-zip*)
			Command="unzip" ;;
		*application/x-gzip*)
			Command="gunzip -d -f" ;;
		*application/x-bzip*)
			Command="bunzip2 -f" ;;
	esac
	if [ "$Command" != "" ]; then
		echo "${Command} ${Archive}"
		${Command} ${Archive} || exit 1
	fi
done

cd ${Source_Duo}

chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

export CFLAGS="-O2 -march=${Flag_Arch} -pipe" 
export CXXFLAGS="${CFLAGS}" 
export PKG_CONFIG_PATH=/usr/lib/pkgconfig
./configure \
--prefix=/usr \
--libdir=/usr/lib \
--mandir=/usr/man \
--disable-static \
--silent

make --silent || exit 1
make install --silent  DESTDIR=${Package_Root} || exit 1


# Special routines:
#_______________________________________________________________________
# Install RadeonHD Utilities:
mkdir -p ${Package_Root}/usr/bin
install -p -m 0755 utils/conntest/rhd_conntest ${Package_Root}/usr/bin/rhd_conntest
install -p -m 0755 utils/conntest/rhd_dump ${Package_Root}/usr/bin/rhd_dump


# Complete the final packaging routines:
#_______________________________________________________________________
mkdir -p ${Package_Root}/usr/doc/${Package_Duo}/
for Each_Doc in {${Special_Docs},${Standard_Docs}} ; do
	if [ -e ${Each_Doc} ] ; then
		cp ${Each_Doc} ${Package_Root}/usr/doc/${Package_Duo}/
	fi
done

( cd ${Package_Root}/usr/doc/${Package_Duo}/
	find . -name "*" -size 0c -exec rm {} \;
)

cd ${Build_Root}
rm -rf ${Source_Duo}

mkdir ${Package_Root}/install
cat <<EOF0 > ${Package_Root}/install/slack-desc
${Package_Name}${Desc_Line_00}
${Package_Name}${Desc_Line_01}
${Package_Name}${Desc_Line_02}
${Package_Name}${Desc_Line_03}
${Package_Name}${Desc_Line_04}
${Package_Name}${Desc_Line_05}
${Package_Name}${Desc_Line_06}
${Package_Name}${Desc_Line_07}
${Package_Name}${Desc_Line_08}
${Package_Name}${Desc_Line_09}
${Package_Name}${Desc_Line_10}
EOF0

mkdir -p ${Package_Root}/usr/src/${Package_Duo}
for Each_Custom in ${Custom_Files} ; do
	if [ -e ${Each_File} ]; then
		cp ${Each_Custom} \
			${Package_Root}/usr/src/${Package_Duo}/
	fi
done

( cd ${Package_Root}
	find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
	find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

if [ -d ${Package_Root}/usr/man ]; then
	( cd ${Package_Root}/usr/man
		gzip -9 */*
	)
fi

( cd ${Package_Root}
	requiredbuilder -z ${Package_Root} > ${Build_Root}/${Package_Title}.dep
)

( cd ${Package_Root}
	makepkg -l y -c n ${Build_Root}/${Package_Title}.tgz
)
cd ${Build_Root}
md5sum ${Package_Title}.tgz > ${Package_Title}.md5
rm -rf ${Package_Root}

mkdir -p ${Package_Root}.src
cp ${Source_Title} ${Package_Root}.src
for Each_Set in ${Custom_Files} ; do
	if [ -e ${Each_Set} ] ; then
		cp ${Each_Set} ${Package_Root}.src
	fi
done
tar -jcf ${Package_Title}.src.tbz ${Package_Title}.src
rm -rf ${Package_Title}.src 
md5sum ${Package_Title}.src.tbz > ${Package_Title}.src.md5


# Changelog of script edits:
#_______________________________________________________________________


# ~ Thu Apr 16th 2009	Michael Verret "axxium" <michael.verret@gmail.com>
# ~ Software: xorg-driver-radeonhd-1.2.5
# ~ Build 62.1

# ~ Fri Mar 13th 2009	Michael Verret "axxium" <michael.verret@gmail.com>
# ~ Software: xorg-driver-radeonhd-1.2.4.20081212.git
# ~ Build 62.2

# ~ Mon Mar 2nd 2009	Michael Verret "axxium" <michael.verret@gmail.com>
# ~ Software: xorg-driver-radeonhd-1.2.4.20081212.git
# ~ Build 62.1

# ~ Thu Feb 12th 2009	Michael Verret "axxium" <michael.verret@gmail.com>
# ~ Software: xorg-driver-radeonhd-1.2.4
# ~ Build 60.1
